@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    SPDX-FileCopyrightText: 2005 David Faure <faure@kde.org>
 
-   SPDX-License-Identifier: LGPL-2.0-only
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef TESTLDAPCLIENT_H
@@ -11,7 +11,8 @@
 
 #include "widgets/ldapclient.h"
 
-namespace KLDAP {
+namespace KLDAP
+{
 class LdapClient;
 class LdapObject;
 }
